<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'info_compresseur_titre' => 'Optimisatioun a Kompressioun',
	'info_question_activer_compactage_css' => 'CSS',
	'info_question_activer_compactage_js' => 'Skripten',
	'item_compresseur_closure' => 'Google Closure Compiler benotzen [experimentell]',
	'item_compresseur_css' => 'Kompressioun vun de Style-Sheets (CSS) aschalten',
	'item_compresseur_js' => 'Kompressioun vun de Skripten (Javascript) aschalten',

	// T
	'texte_compacter_avertissement' => 'Schalt dës Optiounen net während der Entwécklung vum Site an: déi kompriméiert Elementer si net einfach liesbar.',
	'texte_compacter_script_css' => 'SPIP ka Javascript oder CSS Style-Sheets kompriméieren an als statesch Dokumenter späicheren; da ginn d’Säite vum Site méi séier gewisen.',
	'titre_compacter_script_css' => 'Skripten an CSS kompriméieren'
);

?>
